==> flowmachine-1.4.0.post0.dev97-py3-none-any.whl: flowmachine/core/server/query_schemas/total_network_objects.py <==
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

from marshmallow import Schema, fields, post_load
from marshmallow.validate import OneOf, Length

from flowmachine.features import TotalNetworkObjects
from flowmachine.features.network.total_network_objects import valid_periods
from .base_exposed_query import BaseExposedQuery
from .custom_fields import TotalBy
from .aggregation_unit import AggregationUnit, get_spatial_unit_obj

__all__ = ["TotalNetworkObjectsSchema", "TotalNetworkObjectsExposed"]


class TotalNetworkObjectsSchema(Schema):
    # query_kind parameter is required here for claims validation
    query_kind = fields.String(validate=OneOf(["total_network_objects"]))
    start_date = fields.Date(required=True)
    end_date = fields.Date(required=True)
    total_by = TotalBy(required=False, missing="day")
    aggregation_unit = AggregationUnit()

    @post_load
    def make_query_object(self, params, **kwargs):
        return TotalNetworkObjectsExposed(**params)


class TotalNetworkObjectsExposed(BaseExposedQuery):
    def __init__(self, *, start_date, end_date, aggregation_unit, total_by):
        # Note: all input parameters need to be defined as attributes on `self`
        # so that marshmallow can serialise the object correctly.
        self.start_date = start_date
        self.end_date = end_date
        self.aggregation_unit = aggregation_unit
        self.total_by = total_by

    @property
    def _flowmachine_query_obj(self):
        """
        Return the underlying flowmachine daily_location object.

        Returns
        -------
        Query
        """
        return TotalNetworkObjects(
            start=self.start_date,
            stop=self.end_date,
            spatial_unit=get_spatial_unit_obj(self.aggregation_unit),
            total_by=self.total_by,
        )

==> flowmachine-1.8.0.post0.dev52-py3-none-any.whl: flowmachine/core/server/query_schemas/total_network_objects.py <==
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

from marshmallow import fields
from marshmallow.validate import OneOf

from flowmachine.features import TotalNetworkObjects
from .base_exposed_query import BaseExposedQuery
from .base_schema import BaseSchema
from .custom_fields import TotalBy
from .aggregation_unit import AggregationUnit, get_spatial_unit_obj

__all__ = ["TotalNetworkObjectsSchema", "TotalNetworkObjectsExposed"]


class TotalNetworkObjectsExposed(BaseExposedQuery):
    def __init__(self, *, start_date, end_date, aggregation_unit, total_by):
        # Note: all input parameters need to be defined as attributes on `self`
        # so that marshmallow can serialise the object correctly.
        self.start_date = start_date
        self.end_date = end_date
        self.aggregation_unit = aggregation_unit
        self.total_by = total_by

    @property
    def _flowmachine_query_obj(self):
        """
        Return the underlying flowmachine daily_location object.

        Returns
        -------
        Query
        """
        return TotalNetworkObjects(
            start=self.start_date,
            stop=self.end_date,
            spatial_unit=get_spatial_unit_obj(self.aggregation_unit),
            total_by=self.total_by,
        )


class TotalNetworkObjectsSchema(BaseSchema):
    # query_kind parameter is required here for claims validation
    query_kind = fields.String(validate=OneOf(["total_network_objects"]))
    start_date = fields.Date(required=True)
    end_date = fields.Date(required=True)
    total_by = TotalBy(required=False, missing="day")
    aggregation_unit = AggregationUnit()

    __model__ = TotalNetworkObjectsExposed
